pub struct PatchDelete<T: DynTable, S: AsRef<str>, B: AsRef<[u8]>> { /* private fields */ }Expand description
Represents a delete operation in patchset format.
Only stores the table schema and primary key values, as patchsets don’t include full row data for deletions.
Implementations
Sourceimpl<T: DynTable, S: AsRef<str>, B: AsRef<[u8]>> PatchDelete<T, S, B>
impl<T: DynTable, S: AsRef<str>, B: AsRef<[u8]>> PatchDelete<T, S, B>
Sourcepub fn new(table: T, pk: Vec<Value<S, B>>) -> Self
pub fn new(table: T, pk: Vec<Value<S, B>>) -> Self
Create a new patchset delete for the given table and primary key values.
The pk values should be the primary key column values, in the order
they appear in the table schema. This is the same format returned by
crate::SchemaWithPK::extract_pk.