Reverse

Trait Reverse 

pub trait Reverse {
    type Output;

    // Required method
    fn reverse(self) -> Self::Output;
}
Trait for reversing operations.

Reversing a database operation is useful for creating inverse changesets (undo), resolving conflicts in distributed systems, and testing bidirectional synchronization.

Required Associated Types

type Output

The reverse of this operation.

Required Methods

fn reverse(self) -> Self::Output

Returns the reverse of this operation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors