Module schema

Module schema 

Schema traits for compile-time and runtime table definitions.

Structs

SimpleTable
A simple table schema with column names for SQL generation.

Traits

DynTable
A table schema known at runtime (object-safe).
IndexableValues
Collection of indexable values.
NamedColumns
Defines a schema in which the mapping of column names to column positions is known at runtime.
SchemaWithPK
Extension trait for schemas with typed primary key extraction.