SimpleTable

Struct SimpleTable 

pub struct SimpleTable { /* private fields */ }
A simple table schema with column names for SQL generation.

This type wraps TableSchema and adds column names, allowing it to be used for both binary encoding/decoding and SQL statement digestion.

Example

use sqlite_diff_rs::SimpleTable;
use sqlite_diff_rs::{PatchSet, DiffSetBuilder};

let table = SimpleTable::new("users", &["id", "name"], &[0]);
let mut patchset = PatchSet::<SimpleTable, String, Vec<u8>>::new();
patchset.add_table(&table);
patchset.digest_sql("INSERT INTO users (id, name) VALUES (1, 'Alice')").unwrap();

Implementations

Source

impl SimpleTable

pub fn new( name: impl Into<String>, columns: &[&str], pk_indices: &[usize], ) -> Self

Create a new simple table schema.

Arguments
  • name - the table name.
  • columns - column names in order.
  • pk_indices - indices of primary key columns (in PK order).
Panics

Panics if any pk_indices value is out of bounds.

pub fn column_names(&self) -> &[String]

Get the column names.

pub fn column_name(&self, index: usize) -> Option<&str>

Get a column name by index.

pub fn column_index(&self, name: &str) -> Option<usize>

Get the column index by name.

pub fn pk_indices(&self) -> Vec<usize>

Get the indices of primary key columns, in PK order.

pub fn inner(&self) -> &TableSchema<String>

Get the inner TableSchema.