Digestable

Trait Digestable 

pub trait Digestable<F, T, S, B>
where F: Format<S, B>, T: NamedColumns + WireColumnTypes<Self::Src>,
{ type Src: WireSource; type Error; // Required method fn digest_into<Sch, A>( &self, builder: DiffSetBuilder<F, T, S, B>, schema: &Sch, adapter: &A, ) -> Result<DiffSetBuilder<F, T, S, B>, Self::Error> where Sch: WireSchema<Self::Src, Table = T>, A: WireAdapter<Self::Src, S, B>; }
One CDC wire event digested via DiffSetBuilder::digest.

Implemented in-crate for pg_walstream::EventType, wal2json::MessageV2, wal2json::ChangeV1, and maxwell::Message (each times both formats).

Required Associated Types

type Src: WireSource

Wire source this event came from.

type Error

Failure mode raised on schema lookup or decode failure.

Required Methods

fn digest_into<Sch, A>( &self, builder: DiffSetBuilder<F, T, S, B>, schema: &Sch, adapter: &A, ) -> Result<DiffSetBuilder<F, T, S, B>, Self::Error>
where Sch: WireSchema<Self::Src, Table = T>, A: WireAdapter<Self::Src, S, B>,

Fold this event into builder, resolving affected tables via schema and decoding column payloads via adapter.

Errors

Any per-source ConversionError.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors