Builder for constructing changesets and patchsets.
Modules
- sql
- Simplified SQL parser for changeset/patchset operations.
Structs
- Change
Delete - Represents a delete operation in changeset format.
- Changeset
Format - Changeset format marker.
- DiffSet
- A frozen changeset or patchset whose rows are emitted in stored order.
- Diff
SetBuilder - Builder for constructing changeset or patchset binary data.
- Insert
- Builder for an insert operation.
- Patch
Delete - Represents a delete operation in patchset format.
- Patchset
Format - Patchset format marker.
- Update
- Builder for an update operation, parameterized by the format type
Fand value typesS,B.
Enums
- Changeset
Op - View over one operation in a changeset.
- Patchset
Op - View over one operation in a patchset.
Traits
- Column
Names - Trait for tables that can provide column names by index.
- DiffOps
- Trait for adding DML operations (INSERT, DELETE, UPDATE) to a diff set.
- Indirect
- Builders that carry the SQLite session-extension indirect-change flag.
- Reverse
- Trait for reversing operations.
Type Aliases
- Change
Set - Type alias for building changesets.
- Changeset
Update Pair (old, new)value pair stored per column in a changeset UPDATE. Either slot may beNone, which means the column was not part of the diff.- Patch
Set - Type alias for building patchsets.
- Patchset
Update Entry - Entry stored per column in a patchset UPDATE: a unit (the format
does not carry the old value) plus the new value (or
Nonefor unchanged columns).