ChangesetUpdatePair

Type Alias ChangesetUpdatePair 

pub type ChangesetUpdatePair<S, B> = (Option<Value<S, B>>, Option<Value<S, B>>);
(old, new) value pair stored per column in a changeset UPDATE. Either slot may be None, which means the column was not part of the diff.