Schema traits for compile-time and runtime table definitions.
Structs
- Simple
Table - A simple table schema with column names for SQL generation.
Traits
- DynTable
- A table schema known at runtime (object-safe).
- Indexable
Values - Collection of indexable values.
- Named
Columns - Defines a schema in which the mapping of column names to column positions is known at runtime.
- Schema
WithPK - Extension trait for schemas with typed primary key extraction.